@@ -80,4 +80,6 @@ extern "C" {
         item: *mut PyObject,
     ) -> c_int;
     pub fn PyDict_DelItemString(dp: *mut PyObject, key: *const c_char) -> c_int;
+    #[cfg(Py_3_10)]
+    pub fn PyObject_GenericGetDict(obj: *mut PyObject, context: *mut libc::c_void) -> *mut PyObject;
 }
