@@ -1,9 +1,10 @@
 use libc::c_int;
-use object::*;
+
+use crate::object::*;
 
 #[cfg_attr(windows, link(name = "pythonXY"))]
 extern "C" {
-    pub fn PyTraceBack_Here(arg1: *mut ::PyFrameObject) -> c_int;
+    pub fn PyTraceBack_Here(arg1: *mut crate::PyFrameObject) -> c_int;
     pub fn PyTraceBack_Print(arg1: *mut PyObject, arg2: *mut PyObject) -> c_int;
 
     pub static mut PyTraceBack_Type: PyTypeObject;
