@@ -1,6 +1,7 @@
 use libc::c_int;
-use object::*;
-use pyport::Py_ssize_t;
+
+use crate::object::*;
+use crate::pyport::Py_ssize_t;
 
 #[repr(C)]
 #[cfg(not(Py_LIMITED_API))]
@@ -37,6 +38,7 @@ extern "C" {
         arg3: Py_ssize_t,
     ) -> *mut PyObject;
     pub fn PyTuple_Pack(arg1: Py_ssize_t, ...) -> *mut PyObject;
+    #[cfg(not(Py_3_9))]
     pub fn PyTuple_ClearFreeList() -> c_int;
 }
 
